Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2)

Unified Diff: webkit/glue/web_intent_data.h

Issue 9651020: Pass content-type resources to web intents. Goes through download, then invokes the p… (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Move static method location Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webkit/glue/web_intent_data.h
diff --git a/webkit/glue/web_intent_data.h b/webkit/glue/web_intent_data.h
index 78972de59c6496dc7c311ed2567cefdfa88f527b..367b0ea88becb5d4d67d3cf08a25d0ba44eaf166 100644
--- a/webkit/glue/web_intent_data.h
+++ b/webkit/glue/web_intent_data.h
@@ -5,6 +5,8 @@
#ifndef WEBKIT_GLUE_WEB_INTENT_DATA_H_
#define WEBKIT_GLUE_WEB_INTENT_DATA_H_
+#include <map>
+
#include "base/string16.h"
#include "webkit/glue/webkit_glue_export.h"
@@ -23,14 +25,22 @@ struct WEBKIT_GLUE_EXPORT WebIntentData {
// The representation of the payload data. Wire format is from
// SerializedScriptObject.
string16 data;
+ // Any extra key-value pair metadata. (Not serialized.)
+ std::map<string16, string16> extra_data;
// String payload data.
string16 unserialized_data;
+ // The filename of a payload blob.
+ std::string blob_file;
+ // Length of the blob.
+ int64 blob_length;
+
// These enum values indicate which payload data type should be used.
enum DataType {
- SERIALIZED = 0, // The payload is serialized in |data|.
- UNSERIALIZED = 1 // The payload is unseriazed in |unserialized_data|.
+ SERIALIZED = 0, // The payload is serialized in |data|.
+ UNSERIALIZED = 1, // The payload is unserialized in |unserialized_data|.
+ BLOB = 2 // The payload is a blob
};
// Which data payload to use when delivering the intent.
DataType data_type;
@@ -40,6 +50,10 @@ struct WEBKIT_GLUE_EXPORT WebIntentData {
WebIntentData(const string16& action_in,
const string16& type_in,
const string16& unserialized_data_in);
+ WebIntentData(const string16& action_in,
+ const string16& type_in,
+ const std::string& blob_file_in,
+ int64 blob_length_in);
~WebIntentData();
};

Powered by Google App Engine
This is Rietveld 408576698